@@ -1,5 +1,6 @@
 package Symlink::DSL;
-$Symlink::DSL::VERSION = '0.2.3';
+$Symlink::DSL::VERSION = '0.2.4';
+use 5.014;
 use strict;
 use warnings;
 use autodie;
@@ -180,7 +181,7 @@ Symlink::DSL - a domain-specific language for setting up symbolic links.
 
 =head1 VERSION
 
-version 0.2.3
+version 0.2.4
 
 =head1 SYNOPSIS
 
@@ -285,14 +286,6 @@ L<https://metacpan.org/release/Symlink-DSL>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Symlink-DSL>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -301,14 +294,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Symlink-DSL>
 
 =item *
 
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Symlink-DSL>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
